'=============================================================================
' Copyright  Micromega Corporation 2002-2004. All rights reserved
'
' File: graph.bas
'
' This program demonstrates using the uM-FPU V1.0 floating point
' coprocessor with the meLabs PICBASIC Pro compiler. It displays a simple
' graph of the sine and cosine functions using the DEBUG command.
'
' @author Cam Thompson, Micromega Corporation
' @version V1.1 - January 14, 2005
' changes:
'  V1.1 - January 14, 2005
'    - modified to support meLabs PICBASIC Pro compiler
'  V1.0 - April 29, 2004
'    - original version
'=============================================================================

'-------------------- PIC oscillator speed ------------------------------------
define      OSC 20                      'specify the speed of the oscillator
OSC_SPEED   con 20                      'define PICBASIC constant

'-------------------- debug definitions ---------------------------------------
' The routines in umfpuV1-PBP.bas use the DEBUG command to print floating point
' and long integer numbers. The serial pin and baud rate for the DEBUG command
' are specified with the following DEFINES. These should be changed to suit
' your application.

define      DEBUG_REG   PORTC
define      DEBUG_BIT   6
define      DEBUG_BAUD  9600
define      DEBUG_MODE  0

'-------------------- uM-FPU pin definitions ----------------------------------
' The following assignments define the pins used to connect to the uM-FPU V1.0
' chip. These should be changed to suit your application.

FpuClock        var     PORTC.3
FpuDataIn       var     PORTC.4
FpuDataOut      var     PORTC.4

include     "umfpuV1.bas"               'include the uM-FPU support routines

'-------------------- uM-FPU register definitions -----------------------------

Angle           CON     1               'angle            (uM-FPU register 1)
Point           CON     2               'point on graph   (uM-FPU register 2)
Pi              CON     3               'constant Pi      (uM-FPU register 3)
F10_0           CON     4               'constant 10.0    (uM-FPU register 4)
F20_0           CON     5               'constant 20.0    (uM-FPU register 5)

'-------------------- constant definitions -----------------------------------

Space           CON     32              'ASCII character values
Asterisk        CON     42
VerticalLine    CON     124

'-------------------- variables ----------------------------------------------

cnt             VAR     byte            'counter
x               VAR     byte            'x value for graph
p               VAR     byte            'point value for graph

'-------------------- EEPROM data --------------------------------------------

PreloadVector   DATA    Pi
                DATA    $40, $49, $0F, $DB    'pi = 3.1415927
                DATA    F10_0
                DATA    $41, $20, $00, $00    '10.0
                DATA    F20_0
                DATA    $41, $A0, $00, $00    '20.0
                DATA    0

'-------------------- initialization ------------------------------------------

reset:
  DEBUG 13, 10, 13, 10, "Graph", 13, 10

  GOSUB FPU_Reset                       'reset the FPU hardware
  IF fStatus = 0 THEN
    DEBUG "uM-FPU not detected."
    END
  ELSE
    GOSUB FPU_Version                   'display the uM-FPU version number
    DEBUG 13, 10
  ENDIF

  fAddr = PreloadVector                 'load floating point initial values
  GOSUB FPU_Preload

'-------------------- main routine --------------------------------------------

main:
  'graph sine from 0 TO 360 degrees (2*PI radians)
  DEBUG 13, 10, "Graph of sine"
  DEBUG 13, 10, "-1        0        1"
  DEBUG 13, 10, "--------------------", 13, 10

  FOR cnt = 0 TO 20
  fA = Angle                            'angle = Pi
  fb = Pi
  GOSUB Fset

  fLow = 2 * cnt                        'angle = angle * (2 * cnt)
  GOSUB Load_FloatWord
  GOSUB Fmultiply

  fb = F20_0                            'angle = angle / 20.0
  GOSUB Fdivide

  GOSUB Fsin                            'angle = sin(angle)

  GOSUB graph                           'graph the result
  NEXT

  'graph cosine from 0 TO 360 degrees (2*PI radians)
  DEBUG 13, 10, "Graph of cosine"
  DEBUG 13, 10, "-1        0        1"
  DEBUG 13, 10, "--------------------", 13, 10
  FOR cnt = 0 TO 20
    fA = Angle                          'angle = Pi
    fB = Pi
  GOSUB Fset

  fLow = 2 * cnt                        'angle = angle * (2 * cnt)
  GOSUB Load_FloatWord
  GOSUB Fmultiply

  fB = F20_0                            'angle = angle / 20.0
  GOSUB Fdivide

  GOSUB Fcos                            'angle = sin(angle)

  GOSUB graph                           'graph the result
  NEXT

  DEBUG 13, 10, "Done.", 13, 10         'end of program
  END

'-------------------- Graph --------------------------------------------------

Graph:
  fA = Point                            'point = angle
  fB = Angle
  GOSUB Fset

  fA = Point                            'point = point * 10
  fLow = 10
  GOSUB Load_FloatWord
  GOSUB Fmultiply

  GOSUB Fround                          'point = round(point)

  fA = Point                            'point = fix(point)
  fB = Point
  GOSUB Ffix
  GOSUB Fget                            'p = [integer value of]point + 10
  p = fLow.LOWBYTE + 10

  FOR x = 0 TO 20                       'plot the point on graph
    fChar = Space
    IF (x = 10) THEN fChar = VerticalLine
    IF (x = p) THEN fChar = Asterisk
    DEBUG fChar
  NEXT

  DEBUG Space                           'display the original angle
  fA = Angle
  fLow = 85                             '(8.5 format, i.e. width=8, decimals=5)
  GOSUB Print_FloatFormat
  DEBUG 13, 10
  RETURN
