'=============================================================================
' Copyright  Micromega Corporation 2004-2005. All rights reserved
'
' File: sample.bas
'
' Sample routine for uM-FPU V1.0 using meLabs PICBASIC Pro compiler.
'
' @author Cam Thompson, Micromega Corporation
' @version V1.1 - January 14, 2005
' changes:
'  V1.1 - January 14, 2005
'    - modified to support meLabs PICBASIC Pro compiler
'   V1.0 - April 29, 2004
'     - original version
'=============================================================================

'-------------------- PIC oscillator speed ------------------------------------
define      OSC 20                      'specify the speed of the oscillator
OSC_SPEED   con 20                      'define PICBASIC constant

'-------------------- debug definitions ---------------------------------------
' The routines in umfpuV1-PBP.bas use the DEBUG command to print floating point
' and long integer numbers. The serial pin and baud rate for the DEBUG command
' are specified with the following DEFINES. These should be changed to suit
' your application.

define      DEBUG_REG   PORTC
define      DEBUG_BIT   6
define      DEBUG_BAUD  9600
define      DEBUG_MODE  0

'-------------------- uM-FPU pin definitions ----------------------------------
' The following assignments define the pins used to connect to the uM-FPU V1.0
' chip. These should be changed to suit your application.

FpuClock        var     PORTC.3
FpuDataIn       var     PORTC.4
FpuDataOut      var     PORTC.4

include     "umfpuV1.bas"               'include the uM-FPU support routines

'-------------------- uM-FPU register definitions ----------------------------

Result          CON     1               'result
Angle           CON     2               'angle
Multiplier      CON     3               'multiplier
DiameterIn      CON     4               'dimeter in inches
Circumference   CON     5               'circumference
Area            CON     6               'area
Pi              CON     7               'constant pi
F2_0            CON     8               'constant 2.0
F2_54           CON     9               'constant 2.54

'-------------------- variables ----------------------------------------------

diameterCm      VAR     Word            'diameter in centimeters

'-------------------- EEPROM data --------------------------------------------

PreloadVector   DATA    Pi
                DATA    $40, $49, $0F, $DB  'pi = 3.1415927
                DATA    F2_0
                DATA    $40, $00, $00, $00  '2.0
                DATA    F2_54
                DATA    $40, $22, $8F, $5C  '2.54
                DATA    0

Pi_Str          DATA    "3.1415927", 0      'zero terminated string
F20_0Str        DATA    "20.0", 0           'zero terminated string
F20_0           DATA    $41, $A0, $00, $00  '20.0
F0_5            DATA    $3F, $00, $00, $00  '0.5

'-------------------- initialization -----------------------------------------

reset:
  DEBUG 13, 10, "Conversion Example"
  DEBUG 13, 10, "------------------", 13, 10

  GOSUB FPU_Reset                       'reset the FPU hardware
  IF fStatus = 0 THEN
    DEBUG "uM-FPU not detected."
    END
  ELSE
    GOSUB FPU_Version                   'display the uM-FPU version number
    DEBUG 13, 10
  ENDIF

  fAddr = PreloadVector                 'load floating point initial values
  GOSUB FPU_Preload

'-------------------- main routine -------------------------------------------
'The following example takes an integer value representing the diameter
'of a circle in centimeters, converts the value to inches and calculates
'the circumference and area in inches and square inches.

main:

  diameterCm = 25
  DEBUG 13, 10, "Diameter (cm):       ", DEC diameterCm

  'diameterIn = diameterCm / 2.54
  '------------------------------
  fA = DiameterIn                       'diameterIn = diameterCm
  fLow.LOWBYTE = diameterCm
  GOSUB Load_FloatByte
  GOSUB Fset

  fB = F2_54                            'diameterIn = diameterIn / 2.54
  GOSUB fDivide

  DEBUG 13, 10, "Diameter (in.):      "
  GOSUB Print_Float

  'circumference = diameter * pi
  '-----------------------------
  fA = Circumference                    'circumference = diameterIn
  fB = DiameterIn
  GOSUB Fset

  fB = Pi                               'circumference = circumference * pi
  GOSUB Fmultiply

  DEBUG 13, 10, "Circumference (in.): "
  GOSUB Print_Float

  'area = (diameter / 2)^2 * pi
  '----------------------------
  fA = Area                             'area = diameterIn
  fB = DiameterIn
  GOSUB Fset

  fB = F2_0                             'area = area / 2.0
  GOSUB Fdivide

  fB = fA
  GOSUB Fmultiply                       'area = area * area

  fB = Pi
  GOSUB Fmultiply

  DEBUG 13, 10, "Area (sq.in.):       "
  GOSUB Print_Float

  DEBUG 13, 10, "Done.", 13, 10         'end of program
  END
