'==============================================================================
' Copyright  Micromega Corporation 2004-2005. All rights reserved
'
' File: template.bas
'
' This file is intended to be template for developing applications using the
' uM-FPU V1.0 floating point coprocessor with the meLabs PIC Basic Pro compiler.
' The include file umfpuV1-PBP.bas contains all of the support code for the
' uM-FPU. The template program resets the uM-FPU, confirms communications, and
' prints out the version number.  It can be used as a quick initial test that
' the uM-FPU is running, and the file can also be used as a template for
' developing your own applications.
'
' @author Cam Thompson, Micromega Corporation
' @version V1.0 - January 14, 2005
' changes:
'  V1.0 - January 14, 2005
'     - initial version
'==============================================================================

'-------------------- PIC oscillator speed ------------------------------------
define      OSC 20                      'specify the speed of the oscillator
OSC_SPEED   con 20                      'define PICBASIC constant

'-------------------- debug definitions ---------------------------------------
' The routines in umfpuV1-PBP.bas use the DEBUG command to print floating point
' and long integer numbers. The serial pin and baud rate for the DEBUG command
' are specified with the following DEFINES. These should be changed to suit
' your application.

define      DEBUG_REG   PORTC
define      DEBUG_BIT   6
define      DEBUG_BAUD  9600
define      DEBUG_MODE  0

'-------------------- uM-FPU pin definitions ----------------------------------
' The following assignments define the pins used to connect to the uM-FPU V1.0
' chip. These should be changed to suit your application.

FpuClock        var     PORTC.3
FpuDataIn       var     PORTC.4
FpuDataOut      var     PORTC.4

'-------------------- uM-FPU register definitions -----------------------------
' The uM-FPU registers 1 to 15 can be assigned to suit your application.
' The following example defines uM-FPU register 1 as the Result register.

Result          con    1

'-------------------- uM-FPU include ------------------------------------------
' The umfpuV1-PBP.bas file contains the definitions and support code for the
' uM-FPU V1.0 floating point coprocessor.

include "umfpuV1.bas"

'-------------------- initialization ------------------------------------------

reset:
                    'print program name
  debug 13, 10, 13, 10, "Template", 13, 10
                                        '
  gosub FPU_Reset                       'reset the FPU hardware
  if fStatus = 0 then
    debug "uM-FPU not detected."
    end
  else
    gosub FPU_Version                   'display the uM-FPU version number
    debug 13, 10
  endif

  '-----------------------------------------------
  ' Floating point constants would be loaded here.
  ' The following code is a simple example.
  '-----------------------------------------------

  'Set Result register to the value pi.
  '------------------------------------
  fA = Result                           'select Result as the A register
  gosub Load_Pi                         'load the value pi to register 0
  gosub Fset                            'set Result = register 0 (pi)

'-------------------- main routine --------------------------------------------

main:
  '-----------------------------------------
  'Your main routine would be inserted here.
  'The following code is a simple example.
  '-----------------------------------------

  'Print the value of Result (previously set to pi)
  '------------------------------------------------
  debug 13, 10, "Result = "
  fA = Result                           'select Result as A register
  gosub Print_Float                     'print the floating point value

  'Calculate Result = Result / 2.0
  '-------------------------------
  flow = 2                              'load register 0 with 2.0
  gosub Load_FloatByte
  gosub Fdivide                         'divide Result by register 0 (e.g. 2.0)

  'Print the value of Result (pi/2)
  '------------------------------------------------------------
  debug 13, 10, "Result = "
  fA = Result                           'select Result as A register
  gosub Print_Float                     'print the floating point value

  debug 13, 10, "Done.", 13, 10         'end of program
  end
